@@ -62,12 +62,26 @@ Save.prototype.save = function(fileName, fileVersion, overwriteWarning) {
 
     var appWin = EAction.getMainWindow();
     var di = EAction.getDocumentInterface();
+    var buttons, ret;
+
+//    var editingWorkingSet = di.getDocument().isEditingWorkingSet();
+//    if (editingWorkingSet) {
+//        buttons = new QMessageBox.StandardButtons(QMessageBox.Yes, QMessageBox.Cancel);
+//        ret = QMessageBox.warning(
+//                    appWin,
+//                    qsTr("Block editing in progress"),
+//                    qsTr("A block is currently exploded and being edited. Please save the block before saving your drawing.") + " " +
+//                    qsTr("Saving will save the block contents exploded.") + " " +
+//                    qsTr("Save anyway?"), buttons);
+//        if (ret===QMessageBox.Cancel) {
+//            return true;
+//        }
+//    }
 
     fileVersion = isNull(fileVersion) ? "" : fileVersion;
 
     fileName = di.getCorrectedFileName(fileName, fileVersion);
 
-    var buttons, ret;
     var saveAs = false;
 
     if (overwriteWarning) {
@@ -76,7 +90,7 @@ Save.prototype.save = function(fileName, fileVersion, overwriteWarning) {
             ret = QMessageBox.warning(
                         appWin,
                         qsTr("Overwrite File?"),
-                        qsTr("The file '%1' already exists. Do you wish to overwrite it?").arg(fileName), buttons);
+                        qsTr("The file \"%1\" already exists. Do you wish to overwrite it?").arg(fileName), buttons);
             if (ret!=QMessageBox.Yes) {
                 saveAs = true;
             }
@@ -94,10 +108,10 @@ Save.prototype.save = function(fileName, fileVersion, overwriteWarning) {
                 ret = QMessageBox.warning(
                             appWin,
                             qsTr("File Format Version Not Recommended"),
-                            qsTr("The file format version you are using is not recommended: '%1'.").arg(fileVersion) + "\n"
+                            qsTr("The file format version you are using is not recommended: \"%1\".").arg(fileVersion) + "\n"
                             + qsTr("Custom properties will not be saved.") + "\n"
                             + qsTr("All black entities and layers will be saved as white.") + "\n"
-                            + qsTr("All custom colors will be 'rounded' to the nearest fixed color.") + " " + qsTr("Proceed?"), buttons);
+                            + qsTr("All custom colors will be adjusted to the nearest fixed color.") + " " + qsTr("Proceed?"), buttons);
                 if (ret!=QMessageBox.Yes) {
                     saveAs = true;
                 }
@@ -116,9 +130,9 @@ Save.prototype.save = function(fileName, fileVersion, overwriteWarning) {
     appWin.setProgressText(qsTr("Saving..."));
 
     if (noFullColor) {
-        EAction.handleUserWarning(qsTr("Saving to file format version '%1'.").arg(fileVersion));
+        EAction.handleUserWarning(qsTr("Saving to file format version \"%1\".").arg(fileVersion));
         EAction.handleUserWarning(qsTr("Black entities and layers are saved as white."));
-        EAction.handleUserWarning(qsTr("Custom colors are 'rounded' to the nearest fixed color."));
+        EAction.handleUserWarning(qsTr("Custom colors are adjusted to the nearest fixed color."));
     }
 
     var bakFileName = AutoSave.getAutoSaveFileNameCurrent();
@@ -143,7 +157,7 @@ Save.prototype.save = function(fileName, fileVersion, overwriteWarning) {
     }
     RSettings.addRecentFile(fileName);
 
-    appWin.handleUserMessage(qsTr("Saved drawing:") + " " + fileName);
+    appWin.handleUserMessage(qsTr("Saved file:") + " " + fileName);
     if (fileVersion.length!==0) {
         appWin.handleUserMessage(qsTr("Format:") + " " + fileVersion);
     }
